@@ -26,6 +26,9 @@ class ComposeSchema(Schema):
     """
     project_name = fields.String(required=True, default=None)  # default is set in feature _configure_defaults
     network_name = fields.String(required=True, default=None)  # default is set in feature _configure_defaults
+    file_version = fields.String(required=True, default="3.7")
+    service_init = fields.Boolean(required=False, default=True)
+    service_context_root = fields.Boolean(required=False, default=False)
 
 
 class ReverseProxySchema(Schema):
@@ -37,6 +40,7 @@ class ReverseProxySchema(Schema):
     network_names = fields.Dict(required=True, default={"reverse-proxy": "reverse-proxy"})
     certresolver = fields.String(required=False, allow_none=True, default=None)
     redirect_to_https = fields.Boolean(required=False, allow_none=True, default=None)
+    redirect_to_path_prefix = fields.Boolean(required=False, allow_none=True, default=None)
 
 
 class DebugSchema(Schema):
