@@ -23,6 +23,10 @@ class ShellFeature(Feature):
     def name(self) -> str:
         return "shell"
 
+    @property
+    def dependencies(self) -> Iterable[str]:
+        return ["core"]
+
     @property
     def schema(self) -> ClassVar[FeatureSchema]:
         return ShellSchema
