@@ -218,10 +218,10 @@ class TestJsonnetAction:
         assert variables == variables_expected
 
     @pytest.mark.parametrize("variant", [
-        "dev",
-        "ci",
-        "stage",
-        "prod",
+        "test-dev",
+        "test-ci",
+        "test-stage",
+        "test-prod",
     ])
     def test_docker_compose_traefik(self, project_loader, variant):
         def before_load_config():
@@ -344,6 +344,30 @@ class TestJsonnetAction:
 
         assert rendered == expected
 
+    def test_docker_compose_disabled_services(self, project_loader):
+        project_loader("docker_compose_disabled_services")
+
+        features.register(CoreFeature())
+        features.register(FileFeature())
+        features.register(DockerFeature())
+        features.register(JsonnetFeature())
+        load_registered_features()
+        register_actions_in_event_bus(True)
+
+        action = FileWalkAction()
+        action.initialize()
+        action.execute()
+
+        assert os.path.exists('docker-compose.yml')
+        with open('docker-compose.yml', 'r') as f:
+            rendered = yaml.load(f.read(), yaml.SafeLoader)
+
+        with open('docker-compose.expected.yml', 'r') as f:
+            expected_data = f.read()
+            expected = yaml.load(expected_data, yaml.SafeLoader)
+
+        assert rendered == expected
+
     @pytest.mark.parametrize("variant", [
         "_register_binary",
         "_register_binary_with_one_option",
